@@ -51,7 +51,7 @@ class Exceptions:
 
 class IoTDeviceAdvisorClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html)
     """
 
@@ -60,23 +60,24 @@ class IoTDeviceAdvisorClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#can_paginate)
         """
 
     def create_suite_definition(
         self,
+        *,
         suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = None,
-        tags: Dict[str, str] = None,
+        tags: Dict[str, str] = None
     ) -> CreateSuiteDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#create_suite_definition)
         """
 
-    def delete_suite_definition(self, suiteDefinitionId: str) -> Dict[str, Any]:
+    def delete_suite_definition(self, *, suiteDefinitionId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#delete_suite_definition)
         """
 
@@ -88,37 +89,39 @@ class IoTDeviceAdvisorClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#generate_presigned_url)
         """
 
     def get_suite_definition(
-        self, suiteDefinitionId: str, suiteDefinitionVersion: str = None
+        self, *, suiteDefinitionId: str, suiteDefinitionVersion: str = None
     ) -> GetSuiteDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_definition)
         """
 
-    def get_suite_run(self, suiteDefinitionId: str, suiteRunId: str) -> GetSuiteRunResponseTypeDef:
+    def get_suite_run(
+        self, *, suiteDefinitionId: str, suiteRunId: str
+    ) -> GetSuiteRunResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_run)
         """
 
     def get_suite_run_report(
-        self, suiteDefinitionId: str, suiteRunId: str
+        self, *, suiteDefinitionId: str, suiteRunId: str
     ) -> GetSuiteRunReportResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_run_report)
         """
 
     def list_suite_definitions(
-        self, maxResults: int = None, nextToken: str = None
+        self, *, maxResults: int = None, nextToken: str = None
     ) -> ListSuiteDefinitionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_suite_definitions)
         """
 
@@ -131,13 +134,13 @@ class IoTDeviceAdvisorClient:
         nextToken: str = None
     ) -> ListSuiteRunsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_suite_runs)
         """
 
-    def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_tags_for_resource)
         """
 
@@ -150,34 +153,35 @@ class IoTDeviceAdvisorClient:
         tags: Dict[str, str] = None
     ) -> StartSuiteRunResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#start_suite_run)
         """
 
-    def stop_suite_run(self, suiteDefinitionId: str, suiteRunId: str) -> Dict[str, Any]:
+    def stop_suite_run(self, *, suiteDefinitionId: str, suiteRunId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.stop_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.stop_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#stop_suite_run)
         """
 
-    def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#tag_resource)
         """
 
-    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#untag_resource)
         """
 
     def update_suite_definition(
         self,
+        *,
         suiteDefinitionId: str,
-        suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = None,
+        suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = None
     ) -> UpdateSuiteDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#update_suite_definition)
         """
